 clear all
set more off
capture log close

#delimit ;

global X0 "target_lag_2_6 deathinfam delta_income";
global Xresp "male younger middleage some_primary primary morethan_primary havemaize wealth_bline wrdrecal_1 ravens finlit_total relatives";
global Xspouse "spouse_young spouse_middleage spouse_some_primary spouse_morethan_primary spouse_primary spouse_wrdrecal_1 spouse_ravens spouse_finlit_total"; 

//Create database for each value of gamma;
clear;

set obs 21;
local d=0.99;
local s=0.5;

local g0=0;
local g1=1;
local g2=2;

local factor0 = 1;
local factor1 = 1e40;
local factor2 = 1e100;

//Defining the number of gamma values (-1) ;

global ng = 2; 

matrix R =(0.1\0.25\0.5\0.75\1);

gen x1=(_n-1)*100;
replace x1=1e-3 if x1==0;
replace x1=2000-(1e-3) if x1==2000;	


forval r =1/5 {;
gen x2=(2000-x1)*(1+R[`r',1]);
*gen U=ln(x1)+`d'*ln(x2); * Optimal consumption choice does not depend on R since income and substitution effects cancel out with ln utility;
gen U=(x1)^(1-`s')/(1-`s')+`d'*(x2)^(1-`s')/(1-`s');

forval g=0/$ng {;
gen p_num=exp(`g`g''*U)/`factor`g'';
egen p_den=sum(p_num);
gen p`g'_`r'=p_num/p_den;
replace p`g'_`r'=sum(p`g'_`r');
drop p_num p_den;
};
drop x2 U;
};
save "temp_Prob_weight", replace;

//Creating one file of probability weights Pr(x*) for each gamma;
forvalues g = 0/$ng {;
u "temp_Prob_weight", clear;
keep x1 p`g'*; 
xpose, clear;
drop  in 1;
gen indR = _n;
order indR v*;
renpfix v cdf;
sort indR;
save "Prob_weight`g'", replace;
};

clear;

//Simulated data;
cap prog drop sim_res;
prog def sim_res, rclass;

#delimit;
tempname frac0 frac1 frac2 frac3 frac4 frac5 frac6 frac7 frac8 fracequal0 fracequal fracpbias fracfbias fracpb0 fracpb1 fracpb2 fracpb3 fracpb4 fracpb5 
fracfb0 fracfb1 fracfb2 fracfb3 fracfb4 fracfb5 fracrevised bany1 bany2 bany3 bany4;

#delimit cr

matrix R =(0.1\0.25\0.5\0.75\1)

forval g = 0/$ng {
u "sim_data.dta", clear
qui gen indR =_n in 1/5
sort indR
qui merge indR using "Prob_weight`g'"
drop _merge

//Near Choices
forval r = 1/5 {
qui gen rand=uniform()
forval i=1/20 {
qui gen draw`i' = (rand >= cdf`i'[`r'])
}
qui egen n_soon_mk`r' = rowtotal(draw1-draw20)
qui replace n_soon_mk`r'= n_soon_mk`r'*100
qui gen n_late_mk`r' = (2000-n_soon_mk`r')*(1+R[`r',1])
drop rand draw*
}

forval r = 2/5 {
qui gen dcnpossim_`r'=(n_late_mk`r'-n_late_mk`=`r'-1'>=0) if n_late_mk`r'~=. & n_late_mk`=`r'-1'~=.
}

qui egen num_pos_dcns_sim= rowtotal(dcnpossim_2-dcnpossim_5)
drop dcnpossim*

//Far Choices
forval r = 1/5 {
qui gen rand=uniform()
forval i=1/20 {
qui gen draw`i' = (rand >= cdf`i'[`r'])
}
qui egen f_soon_mk`r' = rowtotal(draw1-draw20)
qui replace f_soon_mk`r'= f_soon_mk`r'*100
qui gen f_late_mk`r' = (2000-f_soon_mk`r')*(1+R[`r',1])
drop rand draw*
}
forval r = 2/5 {
qui gen dcfpossim_`r'=(f_late_mk`r'-f_late_mk`=`r'-1'>=0) if f_late_mk`r'~=. & f_late_mk`=`r'-1'~=.
}

qui egen num_pos_dcfs_sim= rowtotal(dcfpossim_2-dcfpossim_5)
drop dcfpossim*

//Fraction Consistent

qui gen tot_num_posdcssim`g'=num_pos_dcfs_sim+num_pos_dcns_sim
qui gen frac_posdcssim`g'=tot_num_posdcssim`g'/8

forval i = 1/9 {
qui gen fr_`i' = (tot_num_posdcssim`g'==`i'-1)
qui sum fr_`i'
matrix `frac`=`i'-1'' = (nullmat(`frac`=`i'-1'') \ r(mean))
drop fr_`i'
}

qui gen presbiassim = 0
qui gen futurebiassim = 0
qui gen consistentsim = 0
qui gen consistentsim0 = 0
qui gen num_sooner = 0

forval r = 1/5 {
qui replace presbiassim = presbiassim + (n_soon_mk`r'>f_soon_mk`r'+100)
qui replace futurebiassim = futurebiassim + (n_soon_mk`r'<f_soon_mk`r'-100)
qui replace consistentsim = consistentsim + (n_soon_mk`r'>=(f_soon_mk`r'-100) & n_soon_mk`r'<=f_soon_mk`r'+100)
qui replace consistentsim0 = consistentsim0 + (n_soon_mk`r'==f_soon_mk`r') 
qui replace num_sooner = num_sooner + n_soon_mk`r' + f_soon_mk`r'
}

qui gen fracpbsim`g'=presbiassim/5
qui gen fracfbsim`g'=futurebiassim/5
qui gen fracconsissim`g'=consistentsim/5
qui gen fracconsissim0`g'=consistentsim0/5
qui gen fracsoonersim`g' = num_sooner/20000 

// Fraction of pairs that are consistent or present / future biased

qui sum consistentsim0
local temp = r(sum)/(_N*5)
matrix `fracequal0' = (nullmat(`fracequal0') \ `temp')
qui sum consistentsim
local temp = r(sum)/(_N*5)
matrix `fracequal' = (nullmat(`fracequal') \ `temp')
qui sum presbiassim
local temp = r(sum)/(_N*5)
matrix `fracpbias' = (nullmat(`fracpbias') \ `temp')
qui sum futurebiassim
local temp = r(sum)/(_N*5)
matrix `fracfbias' = (nullmat(`fracfbias') \ `temp')

// Creating variable elas_diff_average that is used in July 2013 version of Tables

forval r = 1/5 {
    qui gen c2_n_`r' =((2000-n_soon_mk`r')*(1+R[`r',1]))/((2000-n_soon_mk`r')*(1+R[`r',1])+n_soon_mk`r')
    qui gen c2_f_`r' =((2000-f_soon_mk`r')*(1+R[`r',1]))/((2000-f_soon_mk`r')*(1+R[`r',1])+f_soon_mk`r')
}

forval r = 2/5 {
    local r_1 = `r'-1
    qui gen elas_n_`r_1'`r' = (c2_n_`r'-c2_n_`r_1')/(R[`r',1]-R[`r_1',1])
    qui gen elas_f_`r_1'`r' = (c2_f_`r'-c2_f_`r_1')/(R[`r',1]-R[`r_1',1])
}

qui gen elas_n_average = ( elas_n_12+ elas_n_23+ elas_n_34+ elas_n_45)/4
qui gen elas_f_average = ( elas_f_12+ elas_f_23+ elas_f_34+ elas_f_45)/4
qui gen elas_diff_average_sim = elas_f_average-elas_n_average

*Revisit
qui gen impindR = improreturn
qui recode impindR .1 = 1 .25 = 2 .5 = 3 .75 = 4 1 = 5

qui gen rand=uniform()
forval i=1/20 {
qui gen draw`i' = (rand >= cdf`i'[impindR])
}
qui egen revisit_soon_mk = rowtotal(draw1-draw20)
qui replace revisit_soon_mk = revisit_soon_mk*100
qui gen revisit_late_mk = (2000-revisit_soon_mk)*(1+improreturn)

drop rand draw*

* Computing the relevant f_soon_mk based on the implemented interest rate

qui gen ini_soon_mk = 0
qui gen ini_late_mk = 0
qui gen near_soon_mk = 0

forval r = 1/5 {
qui replace ini_soon_mk = f_soon_mk`r' if impindR==`r'
qui replace ini_late_mk = f_late_mk`r' if impindR==`r'
qui replace near_soon_mk = n_soon_mk`r' if impindR==`r'
}
qui replace ini_soon_mk = . if impindR==.
qui replace ini_late_mk = . if impindR==.
qui replace near_soon_mk = . if impindR==.

qui gen dC_1sim`g'=revisit_soon_mk-ini_soon_mk
qui gen revisedsim`g' = (dC_1sim`g'>100 | dC_1sim`g'<-100) if dC_1sim`g'~=.

qui gen ini_pb_sim`g' = (near_soon_mk>ini_soon_mk+100)
qui gen ini_fb_sim`g' = (near_soon_mk<ini_soon_mk-100)

// Fraction of individuals with different number of present and future biased decisions
forval i = 1/5 {
qui gen frpb_`i'`g' = (presbiassim==`i')
qui sum frpb_`i'`g'
matrix `fracpb`i'' = (nullmat(`fracpb`i'') \ r(mean))
qui gen frfb_`i'`g' = (futurebiassim==`i')
qui sum frfb_`i'`g'
matrix `fracfb`i'' = (nullmat(`fracfb`i'') \ r(mean))
}

gen num_sooner_other = num_sooner - ini_soon_mk
gen fracsoonerothersim`g' = num_sooner_other/18000

drop presbiassim futurebiassim consistentsim num_sooner*
 
gen fracpbothersim`g' = round((fracpbsim`g'*5 - ini_pb_sim`g')/4,0.01)
gen fracfbothersim`g' = round((fracfbsim`g'*5 - ini_fb_sim`g')/4,0.01)

replace fracpbothersim`g' = . if impindR==.
replace fracfbothersim`g' = . if impindR==.

qui sum revisedsim`g'
matrix `fracrevised' = (nullmat(`fracrevised') \ r(mean))

qui gen moreelasfarsim`g'=1 if  elas_diff_average_sim>0.1 & elas_diff_average_sim~=. & fracpbsim`g'!=.
qui replace moreelasfarsim`g'=0 if moreelasfarsim`g'==. & elas_diff_average_sim~=. & fracpbsim`g'!=.

qui gen moreelasnearsim`g'=1 if  elas_diff_average_sim<-0.1 & elas_diff_average_sim~=. & fracpbsim`g'!=.
qui replace moreelasnearsim`g'=0 if moreelasnearsim`g'==. & elas_diff_average_sim~=. & fracpbsim`g'!=.

qui gen fracpbothersim_ME`g' = fracpbothersim`g'*moreelasfarsim`g'
qui gen fracfbothersim_ME`g' = fracfbothersim`g'*moreelasnearsim`g'

qui gen fracpbsim_ME`g' = fracpbsim`g'*moreelasfarsim`g'
qui gen fracfbsim_ME`g' = fracfbsim`g'*moreelasnearsim`g'

* Creating spousal variables

bysort hhid (respid): gen nobs = _n

foreach X in frac_posdcssim fracpbsim {
	forvalues y=1/2 {
		bysort hhid: gen temp = `X'`g' if nobs == `y'
		bysort hhid: egen `X'_`y' = max(temp)
		drop temp
	}
	gen spouse_`X'`g' = `X'_1 if nobs == 2
	replace spouse_`X'`g' = `X'_2 if nobs == 1
}
drop frac_posdcssim_1 frac_posdcssim_2 fracpbsim_1 fracpbsim_2

foreach X in n_soon_mk1 n_soon_mk2 n_soon_mk3 n_soon_mk4 n_soon_mk5 f_soon_mk1 f_soon_mk2 f_soon_mk3 f_soon_mk4 f_soon_mk5 n_late_mk1 n_late_mk2 n_late_mk3 n_late_mk4 n_late_mk5 f_late_mk1 f_late_mk2 f_late_mk3 f_late_mk4 f_late_mk5 {
	forvalues y=1/2 {
		bysort hhid: gen temp = `X' if nobs == `y'
		bysort hhid: egen `X'_`y' = max(temp)
		drop temp
	}
	gen spouse_`X' = `X'_1 if nobs == 2
	replace spouse_`X' = `X'_2 if nobs == 1
	drop `X'_*
}

gen spousebias_sim`g' = 0
foreach X in n_soon_mk1 n_soon_mk2 n_soon_mk3 n_soon_mk4 n_soon_mk5 f_soon_mk1 f_soon_mk2 f_soon_mk3 f_soon_mk4 f_soon_mk5 {
	replace spousebias_sim`g' = spousebias_sim`g' + (spouse_`X'-`X')
}

gen spousebias_other_sim`g' = spousebias_sim`g'

gen d_future = floor(own_transfer_card/6)

forvalues r = 1/5 {
	replace spousebias_other_sim`g' = spousebias_other_sim`g' + (n_soon_mk`r' - spouse_n_soon_mk`r') if impindR==`r' & d_future == 0
	replace spousebias_other_sim`g' = spousebias_other_sim`g' + (f_soon_mk`r' - spouse_f_soon_mk`r') if impindR==`r' & d_future == 1
}
drop d_future n_soon_mk* f_soon_mk* n_late_mk* f_late_mk* spouse_n_* spouse_f_*  nobs indR cdf* near_* num_pos_dcns_sim  num_pos_dcfs_sim revisit_* 

replace spousebias_sim`g' = spousebias_sim`g'/10
replace spousebias_other_sim`g' = spousebias_other_sim`g'/9

*Regressions

*1) Using "Present"-Biased ratio
qui xi: reg dC_1sim`g' fracpbsim`g' frac_posdcssim`g' spousebias_sim`g' fracsoonersim`g' fracpbsim_ME`g' moreelasfarsim`g' improreturn spouse_fracpbsim`g' spouse_frac_posdcssim`g' $X0 $Xresp $Xspouse i.z13_month if badsamp==0, robust
local test1 = _b[fracpbsim_ME`g'] + _b[moreelasfarsim`g']
matrix `bany1' = (nullmat(`bany1') \ _b[fracpbsim`g'], _b[frac_posdcssim`g'], _b[spousebias_sim`g'], _b[fracsoonersim`g'], _b[fracpbsim_ME`g'],_b[moreelasfarsim`g'],_b[improreturn], `test1')

qui xi: reg dC_1sim`g' fracpbothersim`g' frac_posdcssim`g' spousebias_other_sim`g' fracsoonerothersim`g' fracpbothersim_ME`g' moreelasfarsim`g' improreturn spouse_fracpbsim`g' spouse_frac_posdcssim`g' $X0 $Xresp $Xspouse i.z13_month  if badsamp==0, robust
local test2 = _b[fracpbothersim_ME`g']+_b[moreelasfarsim`g']
matrix `bany2' = (nullmat(`bany2') \ _b[fracpbothersim`g'], _b[frac_posdcssim`g'], _b[spousebias_other_sim`g'], _b[fracsoonerothersim`g'], _b[fracpbothersim_ME`g'],_b[moreelasfarsim`g'],_b[improreturn], `test2')

*2) Using "Future"-Biased ratio
qui xi: reg dC_1sim`g' fracfbsim`g' frac_posdcssim`g' spousebias_sim`g' fracsoonersim`g' fracfbsim_ME`g' moreelasnearsim`g' improreturn spouse_fracpbsim`g' spouse_frac_posdcssim`g' $X0 $Xresp $Xspouse i.z13_month  if badsamp==0, robust
local test3 = _b[fracfbsim_ME`g'] + _b[moreelasnearsim`g']
matrix `bany3' = (nullmat(`bany3') \ _b[fracfbsim`g'], _b[frac_posdcssim`g'], _b[spousebias_sim`g'], _b[fracsoonersim`g'], _b[fracfbsim_ME`g'],_b[moreelasnearsim`g'], _b[improreturn],`test3')

qui xi: reg dC_1sim`g' fracfbothersim`g' frac_posdcssim`g' spousebias_other_sim`g' fracsoonerothersim`g' fracfbothersim_ME`g' moreelasnearsim`g' improreturn spouse_fracpbsim`g' spouse_frac_posdcssim`g' $X0 $Xresp $Xspouse i.z13_month  if badsamp==0, robust
local test4 = _b[fracsoonerothersim`g'] + _b[fracfbothersim_ME`g']
matrix `bany4' = (nullmat(`bany4') \ _b[fracfbothersim`g'], _b[frac_posdcssim`g'], _b[spousebias_other_sim`g'], _b[fracsoonerothersim`g'], _b[fracfbothersim_ME`g'],_b[moreelasnearsim`g'], _b[improreturn],`test4')
}

forval g = 0/$ng {
forval i = 0/8 {
return scalar frac`i'`g' = `frac`i''[`g'+1,1]
}

return scalar fracequal0`g' = `fracequal0'[`g'+1,1]
return scalar fracequal`g' = `fracequal'[`g'+1,1]
return scalar fracpbias`g' = `fracpbias'[`g'+1,1]
return scalar fracfbias`g' = `fracfbias'[`g'+1,1]

forval i = 1/5 {
return scalar fracpb`i'`g' = `fracpb`i''[`g'+1,1]
}

return scalar fracrevised`g' = `fracrevised'[`g'+1,1]

return scalar bfracpb_any1`g' = `bany1'[`g'+1,1]
return scalar bfracposdc_any1`g' = `bany1'[`g'+1,2]
return scalar bspousebias_any1`g' = `bany1'[`g'+1,3]
return scalar bfracsoon_any1`g' = `bany1'[`g'+1,4]
return scalar bfracpb_ME_any1`g' = `bany1'[`g'+1,5]
return scalar bmoreelasfar_any1`g' = `bany1'[`g'+1,6]
return scalar bimproreturn_any1`g' = `bany1'[`g'+1,7]
return scalar btest_any1`g' = `bany1'[`g'+1,8]

return scalar bfracpbother_any2`g' = `bany2'[`g'+1,1]
return scalar bfracposdc_any2`g' = `bany2'[`g'+1,2]
return scalar bspousebias_any2`g' = `bany2'[`g'+1,3]
return scalar bfracsoon_any2`g' = `bany2'[`g'+1,4]
return scalar bfracpbother_ME_any2`g' = `bany2'[`g'+1,5]
return scalar bmoreelasfar_any2`g' = `bany2'[`g'+1,6]
return scalar bimproreturn_any2`g' = `bany2'[`g'+1,7]
return scalar btest_any2`g' = `bany2'[`g'+1,8]

return scalar bfracfb_any3`g' = `bany3'[`g'+1,1]
return scalar bfracposdc_any3`g' = `bany3'[`g'+1,2]
return scalar bspousebias_any3`g' = `bany3'[`g'+1,3]
return scalar bfracsoon_any3`g' = `bany3'[`g'+1,4]
return scalar bfracfb_ME_any3`g' = `bany3'[`g'+1,5]
return scalar bmoreelasnear_any3`g' = `bany3'[`g'+1,6]
return scalar bimproreturn_any3`g' = `bany3'[`g'+1,7]
return scalar btest_any3`g' = `bany3'[`g'+1,8]

return scalar bfracfbother_any4`g' = `bany4'[`g'+1,1]
return scalar bfracposdc_any4`g' = `bany4'[`g'+1,2]
return scalar bspousebias_any4`g' = `bany4'[`g'+1,3]
return scalar bfracsoon_any4`g' = `bany4'[`g'+1,4]
return scalar bfracfbother_ME_any4`g' = `bany4'[`g'+1,5]
return scalar bmoreelasnear_any4`g' = `bany4'[`g'+1,6]
return scalar bimproreturn_any4`g' = `bany4'[`g'+1,7]
return scalar btest_any4`g' = `bany4'[`g'+1,8]
}
end

#delimit ;
simulate frac00 = r(frac00) frac10 = r(frac10) frac20 = r(frac20) frac30 = r(frac30) frac40 = r(frac40) frac50 = r(frac50) frac60 = r(frac60) frac70 = r(frac70) frac80 = r(frac80)  
frac01 = r(frac01) frac11 = r(frac11) frac21 = r(frac21) frac31 = r(frac31) frac41 = r(frac41) frac51 = r(frac51) frac61 = r(frac61) frac71 = r(frac71) frac81 = r(frac81)  
frac02 = r(frac02) frac12 = r(frac12) frac22 = r(frac22) frac32 = r(frac32) frac42 = r(frac42) frac52 = r(frac52) frac62 = r(frac62) frac72 = r(frac72) frac82 = r(frac82)  

fracequal00 = r(fracequal00) fracequal0 = r(fracequal0) fracpbias0 = r(fracpbias0) fracfbias0 = r(fracfbias0)
fracequal01 = r(fracequal01) fracequal1 = r(fracequal1) fracpbias1 = r(fracpbias1) fracfbias1 = r(fracfbias1)
fracequal02 = r(fracequal02) fracequal2 = r(fracequal2) fracpbias2 = r(fracpbias2) fracfbias2 = r(fracfbias2)

fracpb10 = r(fracpb10) fracpb20 = r(fracpb20) fracpb30 = r(fracpb30) fracpb40 = r(fracpb40) fracpb50 = r(fracpb50) 
fracpb11 = r(fracpb11) fracpb21 = r(fracpb21) fracpb31 = r(fracpb31) fracpb41 = r(fracpb41) fracpb51 = r(fracpb51) 
fracpb12 = r(fracpb12) fracpb22 = r(fracpb22) fracpb32 = r(fracpb32) fracpb42 = r(fracpb42) fracpb52 = r(fracpb52) 

fracrevised0 = r(fracrevised0) fracrevised1 = r(fracrevised1) fracrevised2 = r(fracrevised2) 

bfracpb_any10 = r(bfracpb_any10) bfracpb_any11 = r(bfracpb_any11) bfracpb_any12 = r(bfracpb_any12) 
bfracsoon_any10 = r(bfracsoon_any10) bfracsoon_any11 = r(bfracsoon_any11) bfracsoon_any12 = r(bfracsoon_any12)
bmoreelasfar_any10 = r(bmoreelasfar_any10) bmoreelasfar_any11 = r(bmoreelasfar_any11) bmoreelasfar_any12 = r(bmoreelasfar_any12)
bfracpb_ME_any10 = r(bfracpb_ME_any10) bfracpb_ME_any11 = r(bfracpb_ME_any11) bfracpb_ME_any12 = r(bfracpb_ME_any12)
bfracposdc_any10 = r(bfracposdc_any10) bfracposd_any11 = r(bfracposdc_any11) bfracposd_any12 = r(bfracposdc_any12)
bspousebias_any10 = r(bspousebias_any10) bspousebias_any11 = r(bspousebias_any11) bspousebias_any12 = r(bspousebias_any12)
bimproreturn_any10 = r(bimproreturn_any10) bimproreturn_any11 = r(bimproreturn_any11) bimproreturn_any12 = r(bimproreturn_any12)
btest_any10 = r(btest_any10) btest_any11 = r(btest_any11) btest_any12 = r(btest_any12) 

bfracpbother_any20 = r(bfracpbother_any20) bfracpbother_any21 = r(bfracpbother_any21) bfracpbother_any22 = r(bfracpbother_any22) 
bfracsoon_any20 = r(bfracsoon_any20) bfracsoon_any21 = r(bfracsoon_any21) bfracsoon_any22 = r(bfracsoon_any22)
bmoreelasfar_any20 = r(bmoreelasfar_any20) bmoreelasfar_any21 = r(bmoreelasfar_any21) bmoreelasfar_any22 = r(bmoreelasfar_any22)
bfracpbother_ME_any20 = r(bfracpbother_ME_any20) bfracpbother_ME_any21 = r(bfracpbother_ME_any21) bfracpbother_ME_any22 = r(bfracpbother_ME_any22)
bfracposdc_any20 = r(bfracposdc_any20) bfracposdc_any21 = r(bfracposdc_any21) bfracposdc_any22 = r(bfracposdc_any22) 
bspousebias_any20 = r(bspousebias_any20) bspousebias_any21 = r(bspousebias_any21) bspousebias_any22 = r(bspousebias_any22)
bimproreturn_any20 = r(bimproreturn_any20) bimproreturn_any21 = r(bimproreturn_any21) bimproreturn_any22 = r(bimproreturn_any22)
btest_any20 = r(btest_any20) btest_any21 = r(btest_any21) btest_any22 = r(btest_any22) 

bfracfb_any30 = r(bfracfb_any30) bfracfb_any31 = r(bfracfb_any31) bfracfb_any32 = r(bfracfb_any32) 
bfracsoon_any30 = r(bfracsoon_any30) bfracsoon_any31 = r(bfracsoon_any31) bfracsoon_any32 = r(bfracsoon_any32)
bmoreelasnear_any30 = r(bmoreelasnear_any30) bmoreelasnear_any31 = r(bmoreelasnear_any31) bmoreelasnear_any32 = r(bmoreelasnear_any32)
bfracfb_ME_any30 = r(bfracfb_ME_any30) bfracfb_ME_any31 = r(bfracfb_ME_any31) bfracfb_ME_any32 = r(bfracfb_ME_any32)
bfracposdc_any30 = r(bfracposdc_any30) bfracposd_any31 = r(bfracposdc_any31) bfracposd_any32 = r(bfracposdc_any32)
bspousebias_any30 = r(bspousebias_any30) bspousebias_any31 = r(bspousebias_any31) bspousebias_any32 = r(bspousebias_any32)
bimproreturn_any30 = r(bimproreturn_any30) bimproreturn_any31 = r(bimproreturn_any31) bimproreturn_any32 = r(bimproreturn_any32)
btest_any30 = r(btest_any30) btest_any31 = r(btest_any31) btest_any32 = r(btest_any32) 

bfracfbother_any40 = r(bfracfbother_any40) bfracfbother_any41 = r(bfracfbother_any41) bfracfbother_any42 = r(bfracfbother_any42) 
bfracsoon_any40 = r(bfracsoon_any40) bfracsoon_any41 = r(bfracsoon_any41) bfracsoon_any42 = r(bfracsoon_any42)
bmoreelasnear_any40 = r(bmoreelasnear_any40) bmoreelasnear_any41 = r(bmoreelasnear_any41) bmoreelasnear_any42 = r(bmoreelasnear_any42)
bfracfbother_ME_any40 = r(bfracfbother_ME_any40) bfracfbother_ME_any41 = r(bfracfbother_ME_any41) bfracfbother_ME_any42 = r(bfracfbother_ME_any42)
bfracposdc_any40 = r(bfracposdc_any40) bfracposdc_any41 = r(bfracposdc_any41) bfracposdc_any42 = r(bfracposdc_any42) 
bspousebias_any40 = r(bspousebias_any40) bspousebias_any41 = r(bspousebias_any41) bspousebias_any42 = r(bspousebias_any42)
bimproreturn_any40 = r(bimproreturn_any40) bimproreturn_any41 = r(bimproreturn_any41) bimproreturn_any42 = r(bimproreturn_any42)
btest_any40 = r(btest_any40) btest_any41 = r(btest_any41) btest_any42 = r(btest_any42) 

, saving("sim_output", replace) reps(1000) seed(123456): sim_res;
#delimit cr

unab list:*

log using "sim_results.txt", text replace
tabstat `list', s(count mean sd p5 p95) col(stat)
log close
